==> trade-center-api-0.0.3-20160726.100143-1-sources.jar: cn/com/duiba/order/center/api/dto/ActivityOrderDto.java <==
package cn.com.duiba.order.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * @author houwen
 */
public class ActivityOrderDto implements Serializable {

	/**
	 * 
	 */
	private static final long serialVersionUID = -8801951441959764801L;
	
	private String orderNum;
	private Long consumerId;
	private Long appId;
	private String partnerUserId;
	private Long duibaActivityId;
	private Long appActivityId;
	private String activtyType;
	private Long consumeCredits;
	private Long addCredits;
	private Long activityOptionId;
	private String activityOptionName;
	private String activityOptionType;
	private String facePrice;
	private Long appItemId;
	private Long itemId;
	private Long gid;
	private String gtype;
	private Integer consumeCreditsStatus;
	private Integer exchangeStatus;
	private String ip;
	private Long couponId;
	private String developerBizId;
	private String mainOrderNum;
	private String error4admin;
	private String error4consumer;
	private String error4developer;
	private Date gmtCreate;
	private Date gmtModified;

	public String getOrderNum() {
		return orderNum;
	}

	public void setOrderNum(String orderNum) {
		this.orderNum = orderNum;
	}

	public Long getConsumerId() {
		return consumerId;
	}

	public void setConsumerId(Long consumerId) {
		this.consumerId = consumerId;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public String getPartnerUserId() {
		return partnerUserId;
	}

	public void setPartnerUserId(String partnerUserId) {
		this.partnerUserId = partnerUserId;
	}

	public Long getDuibaActivityId() {
		return duibaActivityId;
	}

	public void setDuibaActivityId(Long duibaActivityId) {
		this.duibaActivityId = duibaActivityId;
	}

	public Long getAppActivityId() {
		return appActivityId;
	}

	public void setAppActivityId(Long appActivityId) {
		this.appActivityId = appActivityId;
	}

	public String getActivtyType() {
		return activtyType;
	}

	public void setActivtyType(String activtyType) {
		this.activtyType = activtyType;
	}

	public Long getConsumeCredits() {
		return consumeCredits;
	}

	public void setConsumeCredits(Long consumeCredits) {
		this.consumeCredits = consumeCredits;
	}

	public Long getAddCredits() {
		return addCredits;
	}

	public void setAddCredits(Long addCredits) {
		this.addCredits = addCredits;
	}

	public Long getActivityOptionId() {
		return activityOptionId;
	}

	public void setActivityOptionId(Long activityOptionId) {
		this.activityOptionId = activityOptionId;
	}

	public String getActivityOptionName() {
		return activityOptionName;
	}

	public void setActivityOptionName(String activityOptionName) {
		this.activityOptionName = activityOptionName;
	}

	public String getActivityOptionType() {
		return activityOptionType;
	}

	public void setActivityOptionType(String activityOptionType) {
		this.activityOptionType = activityOptionType;
	}

	public String getFacePrice() {
		return facePrice;
	}

	public void setFacePrice(String facePrice) {
		this.facePrice = facePrice;
	}

	public Long getAppItemId() {
		return appItemId;
	}

	public void setAppItemId(Long appItemId) {
		this.appItemId = appItemId;
	}

	public Long getItemId() {
		return itemId;
	}

	public void setItemId(Long itemId) {
		this.itemId = itemId;
	}

	public Long getGid() {
		return gid;
	}

	public void setGid(Long gid) {
		this.gid = gid;
	}

	public String getGtype() {
		return gtype;
	}

	public void setGtype(String gtype) {
		this.gtype = gtype;
	}

	public Integer getConsumeCreditsStatus() {
		return consumeCreditsStatus;
	}

	public void setConsumeCreditsStatus(Integer consumeCreditsStatus) {
		this.consumeCreditsStatus = consumeCreditsStatus;
	}

	public Integer getExchangeStatus() {
		return exchangeStatus;
	}

	public void setExchangeStatus(Integer exchangeStatus) {
		this.exchangeStatus = exchangeStatus;
	}

	public String getIp() {
		return ip;
	}

	public void setIp(String ip) {
		this.ip = ip;
	}

	public Long getCouponId() {
		return couponId;
	}

	public void setCouponId(Long couponId) {
		this.couponId = couponId;
	}

	public String getDeveloperBizId() {
		return developerBizId;
	}

	public void setDeveloperBizId(String developerBizId) {
		this.developerBizId = developerBizId;
	}

	public String getMainOrderNum() {
		return mainOrderNum;
	}

	public void setMainOrderNum(String mainOrderNum) {
		this.mainOrderNum = mainOrderNum;
	}

	public String getError4admin() {
		return error4admin;
	}

	public void setError4admin(String error4admin) {
		this.error4admin = error4admin;
	}

	public String getError4consumer() {
		return error4consumer;
	}

	public void setError4consumer(String error4consumer) {
		this.error4consumer = error4consumer;
	}

	public String getError4developer() {
		return error4developer;
	}

	public void setError4developer(String error4developer) {
		this.error4developer = error4developer;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified() {
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}

}

==> trade-center-api-0.1.0-20160803.114630-1-sources.jar: cn/com/duiba/order/center/api/dto/ActivityOrderDto.java <==
package cn.com.duiba.order.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * @author houwen
 */
public class ActivityOrderDto implements Serializable {
	
	/**
	 * 
	 */
	private static final long serialVersionUID = -8801951441959764801L;
	
	public static final int ConsumeCreditsProcessing = 1; // 处理中
	public static final int ConsumeCreditsSuccess = 2;// 成功
	public static final int ConsumeCreditsFail = 3;// 失败

	public static final int ExchangeNone = 0; // 无需领奖
	public static final int ExchangeWait = 1; // 待领将
	public static final int ExchangeSuccess = 2; // 领奖成功
	public static final int ExchangeFail = 3; // 领奖失败
	public static final int ExchangeOverdue = 4; // 过期未领奖失效
	
	public static final String TypeRob = "rob";//今日必抢

	private String orderNum;
	private Long consumerId;
	private Long appId;
	private String partnerUserId;
	private Long duibaActivityId;
	private Long appActivityId;
	private String activityType;
	private Long consumeCredits;
	private Long addCredits;
	private Long activityOptionId;
	private String activityOptionName;
	private String activityOptionType;
	private String facePrice;
	private Long appItemId;
	private Long itemId;
	private Long gid;
	private String gtype;
	private Integer consumeCreditsStatus;
	private Integer exchangeStatus;
	private String ip;
	private Long couponId;
	private String developerBizId;
	private String mainOrderNum;
	private String error4admin;
	private String error4consumer;
	private String error4developer;
	private Date gmtCreate;
	private Date gmtModified;

	public String getOrderNum() {
		return orderNum;
	}

	public void setOrderNum(String orderNum) {
		this.orderNum = orderNum;
	}

	public Long getConsumerId() {
		return consumerId;
	}

	public void setConsumerId(Long consumerId) {
		this.consumerId = consumerId;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public String getPartnerUserId() {
		return partnerUserId;
	}

	public void setPartnerUserId(String partnerUserId) {
		this.partnerUserId = partnerUserId;
	}

	public Long getDuibaActivityId() {
		return duibaActivityId;
	}

	public void setDuibaActivityId(Long duibaActivityId) {
		this.duibaActivityId = duibaActivityId;
	}

	public Long getAppActivityId() {
		return appActivityId;
	}

	public void setAppActivityId(Long appActivityId) {
		this.appActivityId = appActivityId;
	}
	
	public String getActivityType() {
		return activityType;
	}

	public void setActivityType(String activityType) {
		this.activityType = activityType;
	}

	public Long getConsumeCredits() {
		return consumeCredits;
	}

	public void setConsumeCredits(Long consumeCredits) {
		this.consumeCredits = consumeCredits;
	}

	public Long getAddCredits() {
		return addCredits;
	}

	public void setAddCredits(Long addCredits) {
		this.addCredits = addCredits;
	}

	public Long getActivityOptionId() {
		return activityOptionId;
	}

	public void setActivityOptionId(Long activityOptionId) {
		this.activityOptionId = activityOptionId;
	}

	public String getActivityOptionName() {
		return activityOptionName;
	}

	public void setActivityOptionName(String activityOptionName) {
		this.activityOptionName = activityOptionName;
	}

	public String getActivityOptionType() {
		return activityOptionType;
	}

	public void setActivityOptionType(String activityOptionType) {
		this.activityOptionType = activityOptionType;
	}

	public String getFacePrice() {
		return facePrice;
	}

	public void setFacePrice(String facePrice) {
		this.facePrice = facePrice;
	}

	public Long getAppItemId() {
		return appItemId;
	}

	public void setAppItemId(Long appItemId) {
		this.appItemId = appItemId;
	}

	public Long getItemId() {
		return itemId;
	}

	public void setItemId(Long itemId) {
		this.itemId = itemId;
	}

	public Long getGid() {
		return gid;
	}

	public void setGid(Long gid) {
		this.gid = gid;
	}

	public String getGtype() {
		return gtype;
	}

	public void setGtype(String gtype) {
		this.gtype = gtype;
	}

	public Integer getConsumeCreditsStatus() {
		return consumeCreditsStatus;
	}

	public void setConsumeCreditsStatus(Integer consumeCreditsStatus) {
		this.consumeCreditsStatus = consumeCreditsStatus;
	}

	public Integer getExchangeStatus() {
		return exchangeStatus;
	}

	public void setExchangeStatus(Integer exchangeStatus) {
		this.exchangeStatus = exchangeStatus;
	}

	public String getIp() {
		return ip;
	}

	public void setIp(String ip) {
		this.ip = ip;
	}

	public Long getCouponId() {
		return couponId;
	}

	public void setCouponId(Long couponId) {
		this.couponId = couponId;
	}

	public String getDeveloperBizId() {
		return developerBizId;
	}

	public void setDeveloperBizId(String developerBizId) {
		this.developerBizId = developerBizId;
	}

	public String getMainOrderNum() {
		return mainOrderNum;
	}

	public void setMainOrderNum(String mainOrderNum) {
		this.mainOrderNum = mainOrderNum;
	}

	public String getError4admin() {
		return error4admin;
	}

	public void setError4admin(String error4admin) {
		this.error4admin = error4admin;
	}

	public String getError4consumer() {
		return error4consumer;
	}

	public void setError4consumer(String error4consumer) {
		this.error4consumer = error4consumer;
	}

	public String getError4developer() {
		return error4developer;
	}

	public void setError4developer(String error4developer) {
		this.error4developer = error4developer;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified() {
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}

}
